@@ -39,7 +39,7 @@ Light_Sleep_Level_default=70
 Deep_Sleep_Level_default=35
 
 configFileVersion=5 #increase if parameters have changed
-
+configFileVersion_old=0 #keep it 0!
 
 GraphBitMap=""
 GraphBitMapLen=0
@@ -188,12 +188,14 @@ Lucid_Dream_Song_Volume=30
 Lucid_Dream_Song_Delay=600
 Lucid_Dream_Song_Duration = 0
 Lucid_Dream_SongIsActive=False
+Lucid_Dream_Song_Files_in_Folder=0
 
 Use_WakeUp_Song=False
 WakeUp_Song=""
 WakeUp_Song_Volume=50
 WakeUp_Song_Duration=0
 WakeUp_SongIsActive=False
+WakeUp_Song_Files_in_Folder=0
 
 UseAlternativeAlarm=False
 AlternativeAlarm=""
