@@ -70,6 +70,7 @@ def CalculateAlarmtime(h, m):
 ## Returns:     none
 ###########################################################################
 def SetAlarm():
+    Alarm_successfully_set=True
     if(data.DeviceIsN900==True): #We are on a N900
         event = alarm.Event()
         event.appid = 'SleepAnalyser'
@@ -105,9 +106,9 @@ def SetAlarm():
         except:
             print "Could not print event data"
 
-        #python-alarm seems to through an InvalidEventException error if the alarm time is in the past!
+        #python-alarm seems to throw an InvalidEventException error if the alarm time is in the past!
         for i in range(0, 10):
-            print "Try to add alarm event (", i, ")"
+            print "Try to add alarm event (Try", i, "/ 10)"
             try:
                 print "Alarm time:",  event.alarm_time,  "now:",  Tuple2Seconds(time.localtime())
                 data.AlarmID = alarm.add_event(event) #Try to add alarm event
@@ -115,25 +116,31 @@ def SetAlarm():
                 break #alarm is set, leave loop
             except:
                 print "Could not add alarm event, might be in the past"
-                records.AlarmTime_seconds =records.AlarmTime_seconds +1 #move it one second ahead in case its already in the past
+                records.AlarmTime_seconds =records.AlarmTime_seconds +2 #move it one second ahead in case its already in the past
                 event.alarm_time = records.AlarmTime_seconds #in seconds
                 if(i<9): #give it another try
                     pass
                 else:
                     print i+1, "trials without success, raise the error"
                     raise #ok, now really raise the error
+                    Alarm_successfully_set=False #Alarm might not be set successfully! Make sure old alarm (if existing) will not get deleted
 
         print "Ok, could set the alarm"
 
-        event = alarm.get_event(data.AlarmID) #read out again to check if set correctly
-
-        print "* Alarm will go off on:", time.ctime(event.trigger)
+        try:
+            event = alarm.get_event(data.AlarmID) #read out again to check if set correctly
+            print "* Alarm will go off on:", time.ctime(event.trigger)
+        except:
+            print "* Could not read out the alarm again. How ever it might still go off as planed."
+            Alarm_successfully_set=False #Alarm might not be set successfully! Make sure old alarm (if existing) will not get deleted
+            
+            
     else:
         print "* Will not set alarm, Maemo interface not available"
         data.AlarmID=1
 
     data.AlarmIsActive=False
-
+    return Alarm_successfully_set
 
 
 
@@ -200,12 +207,12 @@ def print_list_of_all_alarms():
 ## Parameters:  none
 ## Returns:     none
 ###########################################################################
-def DeleteAlarm():
-    if(data.AlarmID!=-1): #there is an old alarm to be deleted
+def DeleteAlarm(AlarmID):
+    if(AlarmID!=-1): #there is an old alarm to be deleted
         if(data.DeviceIsN900==True): #We are on a N900
             try:
-                event = alarm.get_event(data.AlarmID) #get data of to be deleted alarm
-                alarm.delete_event(data.AlarmID)
+                event = alarm.get_event(AlarmID) #get data of to be deleted alarm
+                alarm.delete_event(AlarmID)
 
                 print "* Delete old alarm:", time.ctime(event.trigger)
             except:
@@ -213,7 +220,7 @@ def DeleteAlarm():
         else:
             print "* Will not delete alarm, Maemo interface not available"
 
-        data.AlarmID=-1
+        AlarmID=-1
 
 #        if(data.AlarmIsActive==False): #if alarm never came, remove from record
 #            records.AlarmTime_seconds=-1
@@ -223,6 +230,7 @@ def DeleteAlarm():
 
     data.AlarmIsActive=False
 
+    return AlarmID
 
 
 
@@ -246,8 +254,8 @@ def ProcessAlarm():
             if(now>=records.AlarmTimeWindowStart_seconds and now<records.AlarmTimeWindowEnd_seconds): # we are in alarm time window
                 if(data.WakeUp_SongIsActive==False):#wake up song (if enabled) is not yet playing
                     print "************ ALARM ALARM (Movement over trigger level)"
-                    print "*", strftime("%x %X"), "ProcessAlarm => DeleteAlarm" #for log file
-                    DeleteAlarm() #delete old alarm if existing
+#                    print "*", strftime("%x %X"), "ProcessAlarm => DeleteAlarm" #for log file
+#                    data.AlarmID=DeleteAlarm(data.AlarmID) #delete old alarm if existing
                     records.AlarmTime_tuple=time.localtime()#set to now
                     records.AlarmTime_seconds=Tuple2Seconds(records.AlarmTime_tuple)
 
@@ -271,7 +279,22 @@ def ProcessAlarm():
                         r=1
 
                     print "*", strftime("%x %X"), "ProcessAlarm => SetAlarm" #for log file
-                    SetAlarm() #set alarm to go off now (or with wake up song delay)
+                    old_AlarmID=data.AlarmID #backup old alarm ID
+                    
+                    try:
+                        Alarm_successfully_set=SetAlarm() #set alarm to go off now (or with wake up song delay)                       
+                    except:
+                        Alarm_successfully_set=False
+                        
+                    if(Alarm_successfully_set==True): #New alarm succesfully set
+                        print "New alarm got sucessfully set, now we can delete the old one"
+                        print "*", strftime("%x %X"), "ProcessAlarm => DeleteAlarm" #for log file
+                        DeleteAlarm(old_AlarmID) #delete old alarm if existing
+                    else: #Could not set new alarm, so do not delete old alarm
+                        print "!!! WARNING !!!!"
+                        print "Could not set new alarm!"
+                        print "Will keep old alarm!"
+
 
                 if(now >= records.AlarmTime_seconds): #alarm is due
                     records.Trigger=data.Trigger #update Trigger level on alarm occurence
